package org.jtheque.filmstobuy.services.impl.file;

/*
 * This file is part of JTheque.
 *
 * JTheque is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License.
 *
 * JTheque is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with JTheque.  If not, see <http://www.gnu.org/licenses/>.
 */

import org.jdom.Document;
import org.jdom.Element;
import org.jtheque.core.managers.Managers;
import org.jtheque.core.managers.beans.IBeansManager;
import org.jtheque.core.managers.file.able.BackupWriter;
import org.jtheque.core.managers.file.able.BasicDataSource;
import org.jtheque.filmstobuy.persistence.od.FilmToBuyImpl;
import org.jtheque.filmstobuy.services.able.IFilmsToBuyService;

import javax.annotation.Resource;

/**
 * A backup writer for a XML Backup.
 *
 * @author Baptiste Wicht
 */
public final class XMLBackupWriter implements BackupWriter {
    @Resource
    private IFilmsToBuyService filmsToBuyService;

    @Override
    public void write(Object object) {
        Document doc = (Document) object;

        Element filmsToBuy = new Element("filmsToBuy");

        for (FilmToBuyImpl film : filmsToBuyService.getFilmsToBuy()) {
            Element filmElement = new Element("film");

            Element id = new Element("id");
            id.setText(Integer.toString(film.getId()));
            filmElement.addContent(id);

            Element date = new Element("date");
            date.setText(Integer.toString(film.getDate().intValue()));
            filmElement.addContent(date);

            Element title = new Element("title");
            title.setText(film.getTitle());
            filmElement.addContent(title);

            filmsToBuy.addContent(filmElement);
        }

        doc.getRootElement().addContent(filmsToBuy);
    }

    @Override
    public void populateDataSource(BasicDataSource datasource) {
    }
}